/*
 * rcktldr.c --- Rocket Modem II microcode loader
 *
 * Written by Theodore Ts'o, 1999
 */


#include <stdio.h>
#include <unistd.h>
#include <stdlib.h>
#include <string.h>
#include <errno.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <sys/ioctl.h>
#include <fcntl.h>

#include "loadrm2.h"

code_t loader_code, firmware_code;
int     debug_flag, ati_flag, progress_flag;

static void usage()
{
  printf("usage: loadrm2 [options] <device-path> [<device-path> ...]\n");
  printf("        -d   enable debug output\n");
  printf("        -i   send ATI command\n");
  printf("        -p   show progress\n");
  printf("\n");
  printf("       examples:  loadrm2 /dev/ttyR0\n");
  printf("                  loadrm2 /dev/ttyR[0-5]\n");
  printf("                  loadrm2 -d /dev/ttyR*\n");
  exit(1);
}

int main(int argc, char **argv)
{
  int c, ret;
  mux m;
  const static char *errmsg = "Couldn't read Rocketmodem II %s file (%d)\n";

  while ((c = getopt(argc, argv, "dip")) != EOF)
    {
      switch (c)
        {
        case 'd':
          debug_flag++;
          break;
        case 'i':
          ati_flag++;
          break;
        case 'p':
          progress_flag++;
          break;
        default:
          usage();

        }
    }

  ret = read_code(PATH_CTMLDR, &loader_code);

  if (ret)
    {
      printf(errmsg, "loader", ret);
      exit(1);
    }

  if (debug_flag)
    printf("Loader size=%d, checksum=0x%lx\n", (int)loader_code->length, loader_code->checksum);

  ret = read_code(PATH_CTMFW, &firmware_code);
  if (ret)
    {
      printf(errmsg, "firmware", ret);
      exit(1);
    }

  if (debug_flag)
    printf("Firmware size=%d, checksum=0x%lx\n", (int)firmware_code->length, firmware_code->checksum);

  if (!argv[optind])
    usage();

  mux_init(&m);

  while (argv[optind])
    {
      ret = port_open(m, argv[optind]);
      if (ret)
        {
          fprintf(stderr, "Couldn't open %s: %s",
                  argv[optind], strerror(ret));
          exit(1);
        }
      optind++;
    }

  if (num_ports == 0)
    return 0;

  mux_loop(m);
  if (num_ports)
    progress_end();

  return 0;
}


