#!/bin/bash
#
#
# Script to write country code in to NVRAM in a modem chip on a
# RocketModem board.  The setting is non-volatile, so it only needs to
# be done once.
#
# Country codes are listed below.  Not all modems support all country
# codes.
# 
#    NotUsed         0
#    Austria         1
#    Belgium         2
#    Denmark         3
#    Finland         4
#    France          5
#    Germany         6
#    Ireland         7
#    Italy           8
#    Luxembourg      9
#    Netherlands     10
#    Norway          11
#    Portugal        12
#    Spain           13
#    Sweden          14
#    Switzerland     15
#    UK              16
#    Greece          17
#    Israel          18
#    CzechRep        19
#    Canada          20
#    Mexico          21
#    USA             22         
#    NorthAmerica    22
#    Hungary         23
#    Poland          24
#    Russia          25
#    SlovacRep       26
#    Bulgaria        27
#    India           30
#    Australia       40
#    China           41
#    HongKong        42
#    Japan           43
#    Philippines     43
#    Korea           44
#    Taiwan          46
#    Singapore       47
#    NewZealand      48
#

flushstdin()
{
    while read -t 0.2 line
    do
        true
    done
}

# read strings from stdin until we get a line that says "OK"
waitOK()
{
    Timeout="$1"
    while read -t $Timeout LINE
    do
        echo "$LINE" >&2
        if [ $(expr "$LINE" : "OK") != 0 ]
        then
            return 0
        fi
    done
    echo "***timeout***" >&2
    return 1
}

# write command in $2 to stdout, then wait up to $1 seconds for "OK"
doCommand()
{
    echo " > '$2'" >&2
    echo -ne "$2"
    waitOK $1
}

# send AT commands to modem to store country code in NVRAM
set_country()
{
    rmdev="$1"
    code="$2"
    (
     stty -echo clocal cread -crtscts -ixon -ixoff cs8 -parenb 115200
     flushstdin
     doCommand 1  "ATH0\r" ||  doCommand 1  "ATH0\r" || doCommand 1  "ATH0\r" ||
       {
           echo >&2
           echo "No response from modem" >&2
           exit 1
       }
     doCommand 10 "AT*NC${code}\r"
     doCommand 1  "ATI5\r"
     flushstdin
     echo >&2
     echo "(ATI5 command above should have printed '$2' or '0$2')" >&2
     echo >&2
    ) <$rmdev >$rmdev
}

test $# -ne 3 ||
{
    echo "Usage: $0 <device-path> <country-code>"
    echo "       example: $0 /dev/ttyR0 22"
    exit 1
}

test -c "$1" ||
{
    echo "Error: $1 not a character device"
    exit 1
}

set_country "$1" "$2"

